# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class PatchCustomer(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Customer object for patch purpose. All fields are optional
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def ban_status() -> typing.Type['BanStatus']:
                return BanStatus
            dob = schemas.DateSchema
            email = schemas.StrSchema
            first_name = schemas.StrSchema
            last_name = schemas.StrSchema
        
            @staticmethod
            def legal_address() -> typing.Type['Address']:
                return Address
            metadata = schemas.DictSchema
            middle_name = schemas.StrSchema
            note = schemas.StrSchema
            
            
            class phone_number(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    regex=[{
                        'pattern': r'^\+[1-9]\d{1,14}$',  # noqa: E501
                    }]
        
            @staticmethod
            def shipping_address() -> typing.Type['Address']:
                return Address
            ssn = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "ACTIVE": "ACTIVE",
                        "ESCHEAT": "ESCHEAT",
                        "DECEASED": "DECEASED",
                        "DENIED": "DENIED",
                        "DORMANT": "DORMANT",
                        "FROZEN": "FROZEN",
                        "INACTIVE": "INACTIVE",
                        "PROSPECT": "PROSPECT",
                        "SANCTION": "SANCTION",
                    }
                
                @schemas.classproperty
                def ACTIVE(cls):
                    return cls("ACTIVE")
                
                @schemas.classproperty
                def ESCHEAT(cls):
                    return cls("ESCHEAT")
                
                @schemas.classproperty
                def DECEASED(cls):
                    return cls("DECEASED")
                
                @schemas.classproperty
                def DENIED(cls):
                    return cls("DENIED")
                
                @schemas.classproperty
                def DORMANT(cls):
                    return cls("DORMANT")
                
                @schemas.classproperty
                def FROZEN(cls):
                    return cls("FROZEN")
                
                @schemas.classproperty
                def INACTIVE(cls):
                    return cls("INACTIVE")
                
                @schemas.classproperty
                def PROSPECT(cls):
                    return cls("PROSPECT")
                
                @schemas.classproperty
                def SANCTION(cls):
                    return cls("SANCTION")
            __annotations__ = {
                "ban_status": ban_status,
                "dob": dob,
                "email": email,
                "first_name": first_name,
                "last_name": last_name,
                "legal_address": legal_address,
                "metadata": metadata,
                "middle_name": middle_name,
                "note": note,
                "phone_number": phone_number,
                "shipping_address": shipping_address,
                "ssn": ssn,
                "status": status,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ban_status"]) -> 'BanStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dob"]) -> MetaOapg.properties.dob: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["first_name"]) -> MetaOapg.properties.first_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_name"]) -> MetaOapg.properties.last_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["legal_address"]) -> 'Address': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["middle_name"]) -> MetaOapg.properties.middle_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["note"]) -> MetaOapg.properties.note: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phone_number"]) -> MetaOapg.properties.phone_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["shipping_address"]) -> 'Address': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ssn"]) -> MetaOapg.properties.ssn: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ban_status", "dob", "email", "first_name", "last_name", "legal_address", "metadata", "middle_name", "note", "phone_number", "shipping_address", "ssn", "status", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ban_status"]) -> typing.Union['BanStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dob"]) -> typing.Union[MetaOapg.properties.dob, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> typing.Union[MetaOapg.properties.email, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["first_name"]) -> typing.Union[MetaOapg.properties.first_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_name"]) -> typing.Union[MetaOapg.properties.last_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["legal_address"]) -> typing.Union['Address', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["middle_name"]) -> typing.Union[MetaOapg.properties.middle_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["note"]) -> typing.Union[MetaOapg.properties.note, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phone_number"]) -> typing.Union[MetaOapg.properties.phone_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["shipping_address"]) -> typing.Union['Address', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ssn"]) -> typing.Union[MetaOapg.properties.ssn, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ban_status", "dob", "email", "first_name", "last_name", "legal_address", "metadata", "middle_name", "note", "phone_number", "shipping_address", "ssn", "status", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        ban_status: typing.Union['BanStatus', schemas.Unset] = schemas.unset,
        dob: typing.Union[MetaOapg.properties.dob, str, date, schemas.Unset] = schemas.unset,
        email: typing.Union[MetaOapg.properties.email, str, schemas.Unset] = schemas.unset,
        first_name: typing.Union[MetaOapg.properties.first_name, str, schemas.Unset] = schemas.unset,
        last_name: typing.Union[MetaOapg.properties.last_name, str, schemas.Unset] = schemas.unset,
        legal_address: typing.Union['Address', schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        middle_name: typing.Union[MetaOapg.properties.middle_name, str, schemas.Unset] = schemas.unset,
        note: typing.Union[MetaOapg.properties.note, str, schemas.Unset] = schemas.unset,
        phone_number: typing.Union[MetaOapg.properties.phone_number, str, schemas.Unset] = schemas.unset,
        shipping_address: typing.Union['Address', schemas.Unset] = schemas.unset,
        ssn: typing.Union[MetaOapg.properties.ssn, str, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PatchCustomer':
        return super().__new__(
            cls,
            *_args,
            ban_status=ban_status,
            dob=dob,
            email=email,
            first_name=first_name,
            last_name=last_name,
            legal_address=legal_address,
            metadata=metadata,
            middle_name=middle_name,
            note=note,
            phone_number=phone_number,
            shipping_address=shipping_address,
            ssn=ssn,
            status=status,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.address import Address
from synctera_client.model.ban_status import BanStatus



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class BaseTransaction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "creation_time",
            "amount",
            "posted_amount",
            "type",
            "pending_amount",
            "dc_sign",
            "force_post",
            "last_updated_time",
            "group_id",
            "subtype",
            "effective_date",
            "partial_hold",
            "transaction_time",
            "currency",
            "id",
            "status",
        }
        
        class properties:
            amount = schemas.Int64Schema
            creation_time = schemas.DateTimeSchema
            currency = schemas.StrSchema
            
            
            class dc_sign(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "DEBIT": "DEBIT",
                        "CREDIT": "CREDIT",
                    }
                
                @schemas.classproperty
                def DEBIT(cls):
                    return cls("DEBIT")
                
                @schemas.classproperty
                def CREDIT(cls):
                    return cls("CREDIT")
            effective_date = schemas.DateSchema
            force_post = schemas.BoolSchema
            group_id = schemas.StrSchema
            id = schemas.UUIDSchema
            last_updated_time = schemas.DateTimeSchema
            partial_hold = schemas.BoolSchema
            pending_amount = schemas.Int64Schema
            posted_amount = schemas.Int64Schema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "PENDING": "PENDING",
                        "DECLINED": "DECLINED",
                        "COMPLETE": "COMPLETE",
                    }
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("PENDING")
                
                @schemas.classproperty
                def DECLINED(cls):
                    return cls("DECLINED")
                
                @schemas.classproperty
                def COMPLETE(cls):
                    return cls("COMPLETE")
            transaction_time = schemas.DateTimeSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "ACH": "ACH",
                        "CARD": "CARD",
                        "CHECK": "CHECK",
                        "EXTERNAL_CARD": "EXTERNAL_CARD",
                        "INTERNAL_TRANSFER": "INTERNAL_TRANSFER",
                        "WIRE": "WIRE",
                    }
                
                @schemas.classproperty
                def ACH(cls):
                    return cls("ACH")
                
                @schemas.classproperty
                def CARD(cls):
                    return cls("CARD")
                
                @schemas.classproperty
                def CHECK(cls):
                    return cls("CHECK")
                
                @schemas.classproperty
                def EXTERNAL_CARD(cls):
                    return cls("EXTERNAL_CARD")
                
                @schemas.classproperty
                def INTERNAL_TRANSFER(cls):
                    return cls("INTERNAL_TRANSFER")
                
                @schemas.classproperty
                def WIRE(cls):
                    return cls("WIRE")
            account_id = schemas.StrSchema
            customer_id = schemas.StrSchema
            
            
            class decline(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "reason",
                        "decline_details",
                    }
                    
                    class properties:
                        decline_details = schemas.StrSchema
                        
                        
                        class reason(
                            schemas.EnumBase,
                            schemas.StrSchema
                        ):
                        
                        
                            class MetaOapg:
                                enum_value_to_name = {
                                    "ACH_RETURN": "ACH_RETURN",
                                    "BALANCE_VIOLATION": "BALANCE_VIOLATION",
                                    "DISABLED_PAYMENT_TYPE": "DISABLED_PAYMENT_TYPE",
                                    "DUPLICATE_TRANSACTION": "DUPLICATE_TRANSACTION",
                                    "GATEWAY_DECLINED": "GATEWAY_DECLINED",
                                    "GATEWAY_ERROR": "GATEWAY_ERROR",
                                    "INSUFFICIENT_FUNDS": "INSUFFICIENT_FUNDS",
                                    "NETWORK_DECLINED": "NETWORK_DECLINED",
                                    "OTHER": "OTHER",
                                    "SUSPECTED_FRAUD": "SUSPECTED_FRAUD",
                                    "TRANSACTION_NOT_PERMITTED": "TRANSACTION_NOT_PERMITTED",
                                }
                            
                            @schemas.classproperty
                            def ACH_RETURN(cls):
                                return cls("ACH_RETURN")
                            
                            @schemas.classproperty
                            def BALANCE_VIOLATION(cls):
                                return cls("BALANCE_VIOLATION")
                            
                            @schemas.classproperty
                            def DISABLED_PAYMENT_TYPE(cls):
                                return cls("DISABLED_PAYMENT_TYPE")
                            
                            @schemas.classproperty
                            def DUPLICATE_TRANSACTION(cls):
                                return cls("DUPLICATE_TRANSACTION")
                            
                            @schemas.classproperty
                            def GATEWAY_DECLINED(cls):
                                return cls("GATEWAY_DECLINED")
                            
                            @schemas.classproperty
                            def GATEWAY_ERROR(cls):
                                return cls("GATEWAY_ERROR")
                            
                            @schemas.classproperty
                            def INSUFFICIENT_FUNDS(cls):
                                return cls("INSUFFICIENT_FUNDS")
                            
                            @schemas.classproperty
                            def NETWORK_DECLINED(cls):
                                return cls("NETWORK_DECLINED")
                            
                            @schemas.classproperty
                            def OTHER(cls):
                                return cls("OTHER")
                            
                            @schemas.classproperty
                            def SUSPECTED_FRAUD(cls):
                                return cls("SUSPECTED_FRAUD")
                            
                            @schemas.classproperty
                            def TRANSACTION_NOT_PERMITTED(cls):
                                return cls("TRANSACTION_NOT_PERMITTED")
                        __annotations__ = {
                            "decline_details": decline_details,
                            "reason": reason,
                        }
                
                reason: MetaOapg.properties.reason
                decline_details: MetaOapg.properties.decline_details
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["decline_details"]) -> MetaOapg.properties.decline_details: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["decline_details", "reason", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["decline_details"]) -> MetaOapg.properties.decline_details: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["decline_details", "reason", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    reason: typing.Union[MetaOapg.properties.reason, str, ],
                    decline_details: typing.Union[MetaOapg.properties.decline_details, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'decline':
                    return super().__new__(
                        cls,
                        *_args,
                        reason=reason,
                        decline_details=decline_details,
                        _configuration=_configuration,
                        **kwargs,
                    )
            description = schemas.StrSchema
        
            @staticmethod
            def enhanced_transaction() -> typing.Type['EnhancedTransactionData']:
                return EnhancedTransactionData
            hold_expiration_time = schemas.DateTimeSchema
            internal_account_id = schemas.StrSchema
            posted_date = schemas.DateSchema
            reference_id = schemas.StrSchema
            system_description = schemas.StrSchema
            __annotations__ = {
                "amount": amount,
                "creation_time": creation_time,
                "currency": currency,
                "dc_sign": dc_sign,
                "effective_date": effective_date,
                "force_post": force_post,
                "group_id": group_id,
                "id": id,
                "last_updated_time": last_updated_time,
                "partial_hold": partial_hold,
                "pending_amount": pending_amount,
                "posted_amount": posted_amount,
                "status": status,
                "transaction_time": transaction_time,
                "type": type,
                "account_id": account_id,
                "customer_id": customer_id,
                "decline": decline,
                "description": description,
                "enhanced_transaction": enhanced_transaction,
                "hold_expiration_time": hold_expiration_time,
                "internal_account_id": internal_account_id,
                "posted_date": posted_date,
                "reference_id": reference_id,
                "system_description": system_description,
            }
    
    creation_time: MetaOapg.properties.creation_time
    amount: MetaOapg.properties.amount
    posted_amount: MetaOapg.properties.posted_amount
    type: MetaOapg.properties.type
    pending_amount: MetaOapg.properties.pending_amount
    dc_sign: MetaOapg.properties.dc_sign
    force_post: MetaOapg.properties.force_post
    last_updated_time: MetaOapg.properties.last_updated_time
    group_id: MetaOapg.properties.group_id
    subtype: schemas.AnyTypeSchema
    effective_date: MetaOapg.properties.effective_date
    partial_hold: MetaOapg.properties.partial_hold
    transaction_time: MetaOapg.properties.transaction_time
    currency: MetaOapg.properties.currency
    id: MetaOapg.properties.id
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dc_sign"]) -> MetaOapg.properties.dc_sign: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["force_post"]) -> MetaOapg.properties.force_post: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["group_id"]) -> MetaOapg.properties.group_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["partial_hold"]) -> MetaOapg.properties.partial_hold: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pending_amount"]) -> MetaOapg.properties.pending_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["posted_amount"]) -> MetaOapg.properties.posted_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decline"]) -> MetaOapg.properties.decline: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enhanced_transaction"]) -> 'EnhancedTransactionData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hold_expiration_time"]) -> MetaOapg.properties.hold_expiration_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["internal_account_id"]) -> MetaOapg.properties.internal_account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["posted_date"]) -> MetaOapg.properties.posted_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reference_id"]) -> MetaOapg.properties.reference_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["system_description"]) -> MetaOapg.properties.system_description: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "creation_time", "currency", "dc_sign", "effective_date", "force_post", "group_id", "id", "last_updated_time", "partial_hold", "pending_amount", "posted_amount", "status", "transaction_time", "type", "account_id", "customer_id", "decline", "description", "enhanced_transaction", "hold_expiration_time", "internal_account_id", "posted_date", "reference_id", "system_description", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dc_sign"]) -> MetaOapg.properties.dc_sign: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["force_post"]) -> MetaOapg.properties.force_post: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["group_id"]) -> MetaOapg.properties.group_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["partial_hold"]) -> MetaOapg.properties.partial_hold: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pending_amount"]) -> MetaOapg.properties.pending_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["posted_amount"]) -> MetaOapg.properties.posted_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> typing.Union[MetaOapg.properties.account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> typing.Union[MetaOapg.properties.customer_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decline"]) -> typing.Union[MetaOapg.properties.decline, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enhanced_transaction"]) -> typing.Union['EnhancedTransactionData', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hold_expiration_time"]) -> typing.Union[MetaOapg.properties.hold_expiration_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["internal_account_id"]) -> typing.Union[MetaOapg.properties.internal_account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["posted_date"]) -> typing.Union[MetaOapg.properties.posted_date, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reference_id"]) -> typing.Union[MetaOapg.properties.reference_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["system_description"]) -> typing.Union[MetaOapg.properties.system_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "creation_time", "currency", "dc_sign", "effective_date", "force_post", "group_id", "id", "last_updated_time", "partial_hold", "pending_amount", "posted_amount", "status", "transaction_time", "type", "account_id", "customer_id", "decline", "description", "enhanced_transaction", "hold_expiration_time", "internal_account_id", "posted_date", "reference_id", "system_description", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        posted_amount: typing.Union[MetaOapg.properties.posted_amount, decimal.Decimal, int, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        pending_amount: typing.Union[MetaOapg.properties.pending_amount, decimal.Decimal, int, ],
        dc_sign: typing.Union[MetaOapg.properties.dc_sign, str, ],
        force_post: typing.Union[MetaOapg.properties.force_post, bool, ],
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, ],
        group_id: typing.Union[MetaOapg.properties.group_id, str, ],
        subtype: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        effective_date: typing.Union[MetaOapg.properties.effective_date, str, date, ],
        partial_hold: typing.Union[MetaOapg.properties.partial_hold, bool, ],
        transaction_time: typing.Union[MetaOapg.properties.transaction_time, str, datetime, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        account_id: typing.Union[MetaOapg.properties.account_id, str, schemas.Unset] = schemas.unset,
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, schemas.Unset] = schemas.unset,
        decline: typing.Union[MetaOapg.properties.decline, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        enhanced_transaction: typing.Union['EnhancedTransactionData', schemas.Unset] = schemas.unset,
        hold_expiration_time: typing.Union[MetaOapg.properties.hold_expiration_time, str, datetime, schemas.Unset] = schemas.unset,
        internal_account_id: typing.Union[MetaOapg.properties.internal_account_id, str, schemas.Unset] = schemas.unset,
        posted_date: typing.Union[MetaOapg.properties.posted_date, str, date, schemas.Unset] = schemas.unset,
        reference_id: typing.Union[MetaOapg.properties.reference_id, str, schemas.Unset] = schemas.unset,
        system_description: typing.Union[MetaOapg.properties.system_description, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BaseTransaction':
        return super().__new__(
            cls,
            *_args,
            creation_time=creation_time,
            amount=amount,
            posted_amount=posted_amount,
            type=type,
            pending_amount=pending_amount,
            dc_sign=dc_sign,
            force_post=force_post,
            last_updated_time=last_updated_time,
            group_id=group_id,
            subtype=subtype,
            effective_date=effective_date,
            partial_hold=partial_hold,
            transaction_time=transaction_time,
            currency=currency,
            id=id,
            status=status,
            account_id=account_id,
            customer_id=customer_id,
            decline=decline,
            description=description,
            enhanced_transaction=enhanced_transaction,
            hold_expiration_time=hold_expiration_time,
            internal_account_id=internal_account_id,
            posted_date=posted_date,
            reference_id=reference_id,
            system_description=system_description,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.enhanced_transaction_data import EnhancedTransactionData



from synctera_client.paths.external_accounts_external_account_id.get import ApiForget
from synctera_client.paths.external_accounts_external_account_id.delete import ApiFordelete
from synctera_client.paths.external_accounts_external_account_id.patch import ApiForpatch


class ExternalAccountsExternalAccountId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class CardStatusReasonCode(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The reason for the card status

Code | Description
--- | ---
NEW | Card activated
REQ | Requested by you
INA | Dormant
UNK | Invalid shipping address
NEG | Negative account balance
REV | Account under review
SUS | Suspicious activity
OUT | Activity outside program parameters
FRD | Confirmed fraud
MAT | Matched with an OFAC list
LOS | Card reported lost
CLO | Card was cloned
COM | Account or card was compromised
TMP | Awaiting customer confirmation
PRC | Initiated by Processor
ISS | Initiated by Issuer
EXP | Card expired
KYC | Failed KYC
INF | Information was validated
ACT | Account activity was validated
AUX | Initiated by a third party
PIN | PIN try limit reached
STO | Card reported stolen
ADD | Address issue
NAM | Name issue
SSN | SSN issue
DOB | DOB issue
EML | Email issue
PHO | Phone issue
FUL | Account/fulfillment mismatch
OTH | Other

    """


    class MetaOapg:
        enum_value_to_name = {
            "NEW": "NEW",
            "REQ": "REQ",
            "INA": "INA",
            "UNK": "UNK",
            "NEG": "NEG",
            "REV": "REV",
            "SUS": "SUS",
            "OUT": "OUT",
            "FRD": "FRD",
            "MAT": "MAT",
            "LOS": "LOS",
            "CLO": "CLO",
            "COM": "COM",
            "TMP": "TMP",
            "PRC": "PRC",
            "ISS": "ISS",
            "EXP": "EXP",
            "KYC": "KYC",
            "INF": "INF",
            "ACT": "ACT",
            "AUX": "AUX",
            "PIN": "PIN",
            "STO": "STO",
            "ADD": "ADD",
            "NAM": "NAM",
            "SSN": "SSN",
            "DOB": "DOB",
            "EML": "EML",
            "PHO": "PHO",
            "FUL": "FUL",
            "OTH": "OTH",
        }
    
    @schemas.classproperty
    def NEW(cls):
        return cls("NEW")
    
    @schemas.classproperty
    def REQ(cls):
        return cls("REQ")
    
    @schemas.classproperty
    def INA(cls):
        return cls("INA")
    
    @schemas.classproperty
    def UNK(cls):
        return cls("UNK")
    
    @schemas.classproperty
    def NEG(cls):
        return cls("NEG")
    
    @schemas.classproperty
    def REV(cls):
        return cls("REV")
    
    @schemas.classproperty
    def SUS(cls):
        return cls("SUS")
    
    @schemas.classproperty
    def OUT(cls):
        return cls("OUT")
    
    @schemas.classproperty
    def FRD(cls):
        return cls("FRD")
    
    @schemas.classproperty
    def MAT(cls):
        return cls("MAT")
    
    @schemas.classproperty
    def LOS(cls):
        return cls("LOS")
    
    @schemas.classproperty
    def CLO(cls):
        return cls("CLO")
    
    @schemas.classproperty
    def COM(cls):
        return cls("COM")
    
    @schemas.classproperty
    def TMP(cls):
        return cls("TMP")
    
    @schemas.classproperty
    def PRC(cls):
        return cls("PRC")
    
    @schemas.classproperty
    def ISS(cls):
        return cls("ISS")
    
    @schemas.classproperty
    def EXP(cls):
        return cls("EXP")
    
    @schemas.classproperty
    def KYC(cls):
        return cls("KYC")
    
    @schemas.classproperty
    def INF(cls):
        return cls("INF")
    
    @schemas.classproperty
    def ACT(cls):
        return cls("ACT")
    
    @schemas.classproperty
    def AUX(cls):
        return cls("AUX")
    
    @schemas.classproperty
    def PIN(cls):
        return cls("PIN")
    
    @schemas.classproperty
    def STO(cls):
        return cls("STO")
    
    @schemas.classproperty
    def ADD(cls):
        return cls("ADD")
    
    @schemas.classproperty
    def NAM(cls):
        return cls("NAM")
    
    @schemas.classproperty
    def SSN(cls):
        return cls("SSN")
    
    @schemas.classproperty
    def DOB(cls):
        return cls("DOB")
    
    @schemas.classproperty
    def EML(cls):
        return cls("EML")
    
    @schemas.classproperty
    def PHO(cls):
        return cls("PHO")
    
    @schemas.classproperty
    def FUL(cls):
        return cls("FUL")
    
    @schemas.classproperty
    def OTH(cls):
        return cls("OTH")



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class OutgoingAch(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Represents a sent ACH transaction.
    """


    class MetaOapg:
        required = {
            "source_account_no",
            "amount",
            "partner_id",
            "bank_id",
            "effective_date",
            "is_same_day",
            "memo",
            "external_id",
            "id",
            "trace_no",
            "account_no",
            "status",
        }
        
        class properties:
            account_no = schemas.StrSchema
            amount = schemas.IntSchema
            bank_id = schemas.IntSchema
            effective_date = schemas.DateSchema
            external_id = schemas.UUIDSchema
            id = schemas.UUIDSchema
            is_same_day = schemas.BoolSchema
            memo = schemas.StrSchema
            partner_id = schemas.IntSchema
            source_account_no = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def INIT(cls):
                    return cls("INIT")
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("PENDING")
                
                @schemas.classproperty
                def CANCELED(cls):
                    return cls("CANCELED")
                
                @schemas.classproperty
                def COMPLETE(cls):
                    return cls("COMPLETE")
                
                @schemas.classproperty
                def DECLINED(cls):
                    return cls("DECLINED")
            trace_no = schemas.StrSchema
            account_name = schemas.StrSchema
            company_entry_description = schemas.StrSchema
            company_name = schemas.StrSchema
        
            @staticmethod
            def hold() -> typing.Type['HoldData']:
                return HoldData
            reference_info = schemas.StrSchema
            source_account_name = schemas.StrSchema
            __annotations__ = {
                "account_no": account_no,
                "amount": amount,
                "bank_id": bank_id,
                "effective_date": effective_date,
                "external_id": external_id,
                "id": id,
                "is_same_day": is_same_day,
                "memo": memo,
                "partner_id": partner_id,
                "source_account_no": source_account_no,
                "status": status,
                "trace_no": trace_no,
                "account_name": account_name,
                "company_entry_description": company_entry_description,
                "company_name": company_name,
                "hold": hold,
                "reference_info": reference_info,
                "source_account_name": source_account_name,
            }
    
    source_account_no: MetaOapg.properties.source_account_no
    amount: MetaOapg.properties.amount
    partner_id: MetaOapg.properties.partner_id
    bank_id: MetaOapg.properties.bank_id
    effective_date: MetaOapg.properties.effective_date
    is_same_day: MetaOapg.properties.is_same_day
    memo: MetaOapg.properties.memo
    external_id: MetaOapg.properties.external_id
    id: MetaOapg.properties.id
    trace_no: MetaOapg.properties.trace_no
    account_no: MetaOapg.properties.account_no
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_no"]) -> MetaOapg.properties.account_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bank_id"]) -> MetaOapg.properties.bank_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["external_id"]) -> MetaOapg.properties.external_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_same_day"]) -> MetaOapg.properties.is_same_day: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["partner_id"]) -> MetaOapg.properties.partner_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source_account_no"]) -> MetaOapg.properties.source_account_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trace_no"]) -> MetaOapg.properties.trace_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_name"]) -> MetaOapg.properties.account_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["company_entry_description"]) -> MetaOapg.properties.company_entry_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["company_name"]) -> MetaOapg.properties.company_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hold"]) -> 'HoldData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reference_info"]) -> MetaOapg.properties.reference_info: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source_account_name"]) -> MetaOapg.properties.source_account_name: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_no", "amount", "bank_id", "effective_date", "external_id", "id", "is_same_day", "memo", "partner_id", "source_account_no", "status", "trace_no", "account_name", "company_entry_description", "company_name", "hold", "reference_info", "source_account_name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_no"]) -> MetaOapg.properties.account_no: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bank_id"]) -> MetaOapg.properties.bank_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["external_id"]) -> MetaOapg.properties.external_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_same_day"]) -> MetaOapg.properties.is_same_day: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["partner_id"]) -> MetaOapg.properties.partner_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source_account_no"]) -> MetaOapg.properties.source_account_no: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trace_no"]) -> MetaOapg.properties.trace_no: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_name"]) -> typing.Union[MetaOapg.properties.account_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["company_entry_description"]) -> typing.Union[MetaOapg.properties.company_entry_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["company_name"]) -> typing.Union[MetaOapg.properties.company_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hold"]) -> typing.Union['HoldData', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reference_info"]) -> typing.Union[MetaOapg.properties.reference_info, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source_account_name"]) -> typing.Union[MetaOapg.properties.source_account_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_no", "amount", "bank_id", "effective_date", "external_id", "id", "is_same_day", "memo", "partner_id", "source_account_no", "status", "trace_no", "account_name", "company_entry_description", "company_name", "hold", "reference_info", "source_account_name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        source_account_no: typing.Union[MetaOapg.properties.source_account_no, str, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        partner_id: typing.Union[MetaOapg.properties.partner_id, decimal.Decimal, int, ],
        bank_id: typing.Union[MetaOapg.properties.bank_id, decimal.Decimal, int, ],
        effective_date: typing.Union[MetaOapg.properties.effective_date, str, date, ],
        is_same_day: typing.Union[MetaOapg.properties.is_same_day, bool, ],
        memo: typing.Union[MetaOapg.properties.memo, str, ],
        external_id: typing.Union[MetaOapg.properties.external_id, str, uuid.UUID, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        trace_no: typing.Union[MetaOapg.properties.trace_no, str, ],
        account_no: typing.Union[MetaOapg.properties.account_no, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        account_name: typing.Union[MetaOapg.properties.account_name, str, schemas.Unset] = schemas.unset,
        company_entry_description: typing.Union[MetaOapg.properties.company_entry_description, str, schemas.Unset] = schemas.unset,
        company_name: typing.Union[MetaOapg.properties.company_name, str, schemas.Unset] = schemas.unset,
        hold: typing.Union['HoldData', schemas.Unset] = schemas.unset,
        reference_info: typing.Union[MetaOapg.properties.reference_info, str, schemas.Unset] = schemas.unset,
        source_account_name: typing.Union[MetaOapg.properties.source_account_name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OutgoingAch':
        return super().__new__(
            cls,
            *_args,
            source_account_no=source_account_no,
            amount=amount,
            partner_id=partner_id,
            bank_id=bank_id,
            effective_date=effective_date,
            is_same_day=is_same_day,
            memo=memo,
            external_id=external_id,
            id=id,
            trace_no=trace_no,
            account_no=account_no,
            status=status,
            account_name=account_name,
            company_entry_description=company_entry_description,
            company_name=company_name,
            hold=hold,
            reference_info=reference_info,
            source_account_name=source_account_name,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.hold_data import HoldData



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class EnhancedTransactionData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enriched transaction metadata
    """


    class MetaOapg:
        
        class properties:
            category = schemas.StrSchema
            enhanced_description = schemas.StrSchema
            
            
            class enhanced_raw(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                amount = schemas.NumberSchema
                                categorized_by = schemas.IntSchema
                                category = schemas.StrSchema
                                category_guid = schemas.StrSchema
                                described_by = schemas.IntSchema
                                description = schemas.StrSchema
                                extended_transaction_type = schemas.StrSchema
                                id = schemas.IntSchema
                                is_bill_pay = schemas.BoolSchema
                                is_direct_deposit = schemas.BoolSchema
                                is_expense = schemas.BoolSchema
                                is_fee = schemas.BoolSchema
                                is_income = schemas.BoolSchema
                                is_international = schemas.BoolSchema
                                is_overdraft_fee = schemas.BoolSchema
                                is_payroll_advance = schemas.BoolSchema
                                is_subscription = schemas.BoolSchema
                                memo = schemas.StrSchema
                                merchant_category_code = schemas.IntSchema
                                merchant_guid = schemas.StrSchema
                                merchant_location_guid = schemas.StrSchema
                                original_description = schemas.StrSchema
                                type = schemas.StrSchema
                                __annotations__ = {
                                    "amount": amount,
                                    "categorized_by": categorized_by,
                                    "category": category,
                                    "category_guid": category_guid,
                                    "described_by": described_by,
                                    "description": description,
                                    "extended_transaction_type": extended_transaction_type,
                                    "id": id,
                                    "is_bill_pay": is_bill_pay,
                                    "is_direct_deposit": is_direct_deposit,
                                    "is_expense": is_expense,
                                    "is_fee": is_fee,
                                    "is_income": is_income,
                                    "is_international": is_international,
                                    "is_overdraft_fee": is_overdraft_fee,
                                    "is_payroll_advance": is_payroll_advance,
                                    "is_subscription": is_subscription,
                                    "memo": memo,
                                    "merchant_category_code": merchant_category_code,
                                    "merchant_guid": merchant_guid,
                                    "merchant_location_guid": merchant_location_guid,
                                    "original_description": original_description,
                                    "type": type,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["categorized_by"]) -> MetaOapg.properties.categorized_by: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["category"]) -> MetaOapg.properties.category: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["category_guid"]) -> MetaOapg.properties.category_guid: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["described_by"]) -> MetaOapg.properties.described_by: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["extended_transaction_type"]) -> MetaOapg.properties.extended_transaction_type: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_bill_pay"]) -> MetaOapg.properties.is_bill_pay: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_direct_deposit"]) -> MetaOapg.properties.is_direct_deposit: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_expense"]) -> MetaOapg.properties.is_expense: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_fee"]) -> MetaOapg.properties.is_fee: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_income"]) -> MetaOapg.properties.is_income: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_international"]) -> MetaOapg.properties.is_international: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_overdraft_fee"]) -> MetaOapg.properties.is_overdraft_fee: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_payroll_advance"]) -> MetaOapg.properties.is_payroll_advance: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["is_subscription"]) -> MetaOapg.properties.is_subscription: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["merchant_category_code"]) -> MetaOapg.properties.merchant_category_code: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["merchant_guid"]) -> MetaOapg.properties.merchant_guid: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["merchant_location_guid"]) -> MetaOapg.properties.merchant_location_guid: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["original_description"]) -> MetaOapg.properties.original_description: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "categorized_by", "category", "category_guid", "described_by", "description", "extended_transaction_type", "id", "is_bill_pay", "is_direct_deposit", "is_expense", "is_fee", "is_income", "is_international", "is_overdraft_fee", "is_payroll_advance", "is_subscription", "memo", "merchant_category_code", "merchant_guid", "merchant_location_guid", "original_description", "type", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union[MetaOapg.properties.amount, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["categorized_by"]) -> typing.Union[MetaOapg.properties.categorized_by, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["category"]) -> typing.Union[MetaOapg.properties.category, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["category_guid"]) -> typing.Union[MetaOapg.properties.category_guid, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["described_by"]) -> typing.Union[MetaOapg.properties.described_by, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["extended_transaction_type"]) -> typing.Union[MetaOapg.properties.extended_transaction_type, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_bill_pay"]) -> typing.Union[MetaOapg.properties.is_bill_pay, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_direct_deposit"]) -> typing.Union[MetaOapg.properties.is_direct_deposit, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_expense"]) -> typing.Union[MetaOapg.properties.is_expense, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_fee"]) -> typing.Union[MetaOapg.properties.is_fee, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_income"]) -> typing.Union[MetaOapg.properties.is_income, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_international"]) -> typing.Union[MetaOapg.properties.is_international, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_overdraft_fee"]) -> typing.Union[MetaOapg.properties.is_overdraft_fee, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_payroll_advance"]) -> typing.Union[MetaOapg.properties.is_payroll_advance, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["is_subscription"]) -> typing.Union[MetaOapg.properties.is_subscription, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["memo"]) -> typing.Union[MetaOapg.properties.memo, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["merchant_category_code"]) -> typing.Union[MetaOapg.properties.merchant_category_code, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["merchant_guid"]) -> typing.Union[MetaOapg.properties.merchant_guid, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["merchant_location_guid"]) -> typing.Union[MetaOapg.properties.merchant_location_guid, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["original_description"]) -> typing.Union[MetaOapg.properties.original_description, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "categorized_by", "category", "category_guid", "described_by", "description", "extended_transaction_type", "id", "is_bill_pay", "is_direct_deposit", "is_expense", "is_fee", "is_income", "is_international", "is_overdraft_fee", "is_payroll_advance", "is_subscription", "memo", "merchant_category_code", "merchant_guid", "merchant_location_guid", "original_description", "type", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *_args: typing.Union[dict, frozendict.frozendict, ],
                            amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
                            categorized_by: typing.Union[MetaOapg.properties.categorized_by, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                            category: typing.Union[MetaOapg.properties.category, str, schemas.Unset] = schemas.unset,
                            category_guid: typing.Union[MetaOapg.properties.category_guid, str, schemas.Unset] = schemas.unset,
                            described_by: typing.Union[MetaOapg.properties.described_by, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                            description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
                            extended_transaction_type: typing.Union[MetaOapg.properties.extended_transaction_type, str, schemas.Unset] = schemas.unset,
                            id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                            is_bill_pay: typing.Union[MetaOapg.properties.is_bill_pay, bool, schemas.Unset] = schemas.unset,
                            is_direct_deposit: typing.Union[MetaOapg.properties.is_direct_deposit, bool, schemas.Unset] = schemas.unset,
                            is_expense: typing.Union[MetaOapg.properties.is_expense, bool, schemas.Unset] = schemas.unset,
                            is_fee: typing.Union[MetaOapg.properties.is_fee, bool, schemas.Unset] = schemas.unset,
                            is_income: typing.Union[MetaOapg.properties.is_income, bool, schemas.Unset] = schemas.unset,
                            is_international: typing.Union[MetaOapg.properties.is_international, bool, schemas.Unset] = schemas.unset,
                            is_overdraft_fee: typing.Union[MetaOapg.properties.is_overdraft_fee, bool, schemas.Unset] = schemas.unset,
                            is_payroll_advance: typing.Union[MetaOapg.properties.is_payroll_advance, bool, schemas.Unset] = schemas.unset,
                            is_subscription: typing.Union[MetaOapg.properties.is_subscription, bool, schemas.Unset] = schemas.unset,
                            memo: typing.Union[MetaOapg.properties.memo, str, schemas.Unset] = schemas.unset,
                            merchant_category_code: typing.Union[MetaOapg.properties.merchant_category_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                            merchant_guid: typing.Union[MetaOapg.properties.merchant_guid, str, schemas.Unset] = schemas.unset,
                            merchant_location_guid: typing.Union[MetaOapg.properties.merchant_location_guid, str, schemas.Unset] = schemas.unset,
                            original_description: typing.Union[MetaOapg.properties.original_description, str, schemas.Unset] = schemas.unset,
                            type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *_args,
                                amount=amount,
                                categorized_by=categorized_by,
                                category=category,
                                category_guid=category_guid,
                                described_by=described_by,
                                description=description,
                                extended_transaction_type=extended_transaction_type,
                                id=id,
                                is_bill_pay=is_bill_pay,
                                is_direct_deposit=is_direct_deposit,
                                is_expense=is_expense,
                                is_fee=is_fee,
                                is_income=is_income,
                                is_international=is_international,
                                is_overdraft_fee=is_overdraft_fee,
                                is_payroll_advance=is_payroll_advance,
                                is_subscription=is_subscription,
                                memo=memo,
                                merchant_category_code=merchant_category_code,
                                merchant_guid=merchant_guid,
                                merchant_location_guid=merchant_location_guid,
                                original_description=original_description,
                                type=type,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'enhanced_raw':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "category": category,
                "enhanced_description": enhanced_description,
                "enhanced_raw": enhanced_raw,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["category"]) -> MetaOapg.properties.category: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enhanced_description"]) -> MetaOapg.properties.enhanced_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enhanced_raw"]) -> MetaOapg.properties.enhanced_raw: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["category", "enhanced_description", "enhanced_raw", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["category"]) -> typing.Union[MetaOapg.properties.category, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enhanced_description"]) -> typing.Union[MetaOapg.properties.enhanced_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enhanced_raw"]) -> typing.Union[MetaOapg.properties.enhanced_raw, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["category", "enhanced_description", "enhanced_raw", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        category: typing.Union[MetaOapg.properties.category, str, schemas.Unset] = schemas.unset,
        enhanced_description: typing.Union[MetaOapg.properties.enhanced_description, str, schemas.Unset] = schemas.unset,
        enhanced_raw: typing.Union[MetaOapg.properties.enhanced_raw, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'EnhancedTransactionData':
        return super().__new__(
            cls,
            *_args,
            category=category,
            enhanced_description=enhanced_description,
            enhanced_raw=enhanced_raw,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Status1(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Status of the person. One of the following:
* `ACTIVE` – is an integrator defined status.  Integrators should set a person to active if they believe the person to be qualified for conducting business.  Synctera will combine this status with other statuses such a verification to determine if the person is eligible for specific actions such as initiating transactions or issuing a card.
* `DECEASED` – person is deceased.
* `DENIED` – customer was turned down.
* `DORMANT` – person is no longer active.
* `ESCHEAT` – person's assets are abandoned and are property of the state.
* `FROZEN` – person's actions are blocked for security, legal, or other reasons.
* `INACTIVE` – an inactive status indicating that the person is no longer active.
* `PROSPECT` – a potential customer, used for information-gathering and disclosures.
* `SANCTION` – person is on a sanctions list and should be carefully monitored.

    """
    
    @schemas.classproperty
    def ACTIVE(cls):
        return cls("ACTIVE")
    
    @schemas.classproperty
    def DECEASED(cls):
        return cls("DECEASED")
    
    @schemas.classproperty
    def DENIED(cls):
        return cls("DENIED")
    
    @schemas.classproperty
    def DORMANT(cls):
        return cls("DORMANT")
    
    @schemas.classproperty
    def ESCHEAT(cls):
        return cls("ESCHEAT")
    
    @schemas.classproperty
    def FROZEN(cls):
        return cls("FROZEN")
    
    @schemas.classproperty
    def INACTIVE(cls):
        return cls("INACTIVE")
    
    @schemas.classproperty
    def PROSPECT(cls):
        return cls("PROSPECT")
    
    @schemas.classproperty
    def SANCTION(cls):
        return cls("SANCTION")



from synctera_client.paths.cards_images_card_image_id_data.get import ApiForget
from synctera_client.paths.cards_images_card_image_id_data.post import ApiForpost


class CardsImagesCardImageIdData(
    ApiForget,
    ApiForpost,
):
    pass



from synctera_client.paths.monitoring_subscriptions_subscription_id.get import ApiForget
from synctera_client.paths.monitoring_subscriptions_subscription_id.delete import ApiFordelete


class MonitoringSubscriptionsSubscriptionId(
    ApiForget,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class BaseCard(
    schemas.ComposedSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class all_of_1(
            schemas.DictSchema
        ):
        
        
            class MetaOapg:
                required = {
                    "form",
                }
                
                class properties:
                    account_id = schemas.UUIDSchema
                    card_product_id = schemas.UUIDSchema
                    creation_time = schemas.DateTimeSchema
                    customer_id = schemas.UUIDSchema
                
                    @staticmethod
                    def emboss_name() -> typing.Type['EmbossName']:
                        return EmbossName
                    expiration_month = schemas.StrSchema
                    expiration_time = schemas.DateTimeSchema
                    expiration_year = schemas.StrSchema
                    id = schemas.UUIDSchema
                    is_pin_set = schemas.BoolSchema
                    last_four = schemas.StrSchema
                    last_modified_time = schemas.DateTimeSchema
                
                    @staticmethod
                    def metadata() -> typing.Type['CardMetadata']:
                        return CardMetadata
                    
                    
                    class reissue_reason(
                        schemas.EnumBase,
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            enum_value_to_name = {
                                "EXPIRATION": "EXPIRATION",
                                "LOST": "LOST",
                                "STOLEN": "STOLEN",
                                "DAMAGED": "DAMAGED",
                                "NAME_CHANGE": "NAME_CHANGE",
                                "VIRTUAL_TO_PHYSICAL": "VIRTUAL_TO_PHYSICAL",
                                "PRODUCT_CHANGE": "PRODUCT_CHANGE",
                                "APPEARANCE": "APPEARANCE",
                            }
                        
                        @schemas.classproperty
                        def EXPIRATION(cls):
                            return cls("EXPIRATION")
                        
                        @schemas.classproperty
                        def LOST(cls):
                            return cls("LOST")
                        
                        @schemas.classproperty
                        def STOLEN(cls):
                            return cls("STOLEN")
                        
                        @schemas.classproperty
                        def DAMAGED(cls):
                            return cls("DAMAGED")
                        
                        @schemas.classproperty
                        def NAME_CHANGE(cls):
                            return cls("NAME_CHANGE")
                        
                        @schemas.classproperty
                        def VIRTUAL_TO_PHYSICAL(cls):
                            return cls("VIRTUAL_TO_PHYSICAL")
                        
                        @schemas.classproperty
                        def PRODUCT_CHANGE(cls):
                            return cls("PRODUCT_CHANGE")
                        
                        @schemas.classproperty
                        def APPEARANCE(cls):
                            return cls("APPEARANCE")
                    reissued_from_id = schemas.UUIDSchema
                    reissued_to_id = schemas.UUIDSchema
                    
                    
                    class type(
                        schemas.EnumBase,
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            enum_value_to_name = {
                                "DEBIT": "DEBIT",
                            }
                        
                        @schemas.classproperty
                        def DEBIT(cls):
                            return cls("DEBIT")
                    __annotations__ = {
                        "account_id": account_id,
                        "card_product_id": card_product_id,
                        "creation_time": creation_time,
                        "customer_id": customer_id,
                        "emboss_name": emboss_name,
                        "expiration_month": expiration_month,
                        "expiration_time": expiration_time,
                        "expiration_year": expiration_year,
                        "id": id,
                        "is_pin_set": is_pin_set,
                        "last_four": last_four,
                        "last_modified_time": last_modified_time,
                        "metadata": metadata,
                        "reissue_reason": reissue_reason,
                        "reissued_from_id": reissued_from_id,
                        "reissued_to_id": reissued_to_id,
                        "type": type,
                    }
            
            form: schemas.AnyTypeSchema
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["card_product_id"]) -> MetaOapg.properties.card_product_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["emboss_name"]) -> 'EmbossName': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["expiration_month"]) -> MetaOapg.properties.expiration_month: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["expiration_time"]) -> MetaOapg.properties.expiration_time: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["expiration_year"]) -> MetaOapg.properties.expiration_year: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["is_pin_set"]) -> MetaOapg.properties.is_pin_set: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["last_four"]) -> MetaOapg.properties.last_four: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["last_modified_time"]) -> MetaOapg.properties.last_modified_time: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'CardMetadata': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["reissue_reason"]) -> MetaOapg.properties.reissue_reason: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["reissued_from_id"]) -> MetaOapg.properties.reissued_from_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["reissued_to_id"]) -> MetaOapg.properties.reissued_to_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_id", "card_product_id", "creation_time", "customer_id", "emboss_name", "expiration_month", "expiration_time", "expiration_year", "id", "is_pin_set", "last_four", "last_modified_time", "metadata", "reissue_reason", "reissued_from_id", "reissued_to_id", "type", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> typing.Union[MetaOapg.properties.account_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["card_product_id"]) -> typing.Union[MetaOapg.properties.card_product_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> typing.Union[MetaOapg.properties.customer_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["emboss_name"]) -> typing.Union['EmbossName', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["expiration_month"]) -> typing.Union[MetaOapg.properties.expiration_month, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["expiration_time"]) -> typing.Union[MetaOapg.properties.expiration_time, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["expiration_year"]) -> typing.Union[MetaOapg.properties.expiration_year, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["is_pin_set"]) -> typing.Union[MetaOapg.properties.is_pin_set, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["last_four"]) -> typing.Union[MetaOapg.properties.last_four, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["last_modified_time"]) -> typing.Union[MetaOapg.properties.last_modified_time, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union['CardMetadata', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["reissue_reason"]) -> typing.Union[MetaOapg.properties.reissue_reason, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["reissued_from_id"]) -> typing.Union[MetaOapg.properties.reissued_from_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["reissued_to_id"]) -> typing.Union[MetaOapg.properties.reissued_to_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_id", "card_product_id", "creation_time", "customer_id", "emboss_name", "expiration_month", "expiration_time", "expiration_year", "id", "is_pin_set", "last_four", "last_modified_time", "metadata", "reissue_reason", "reissued_from_id", "reissued_to_id", "type", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *_args: typing.Union[dict, frozendict.frozendict, ],
                form: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                account_id: typing.Union[MetaOapg.properties.account_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                card_product_id: typing.Union[MetaOapg.properties.card_product_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
                customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                emboss_name: typing.Union['EmbossName', schemas.Unset] = schemas.unset,
                expiration_month: typing.Union[MetaOapg.properties.expiration_month, str, schemas.Unset] = schemas.unset,
                expiration_time: typing.Union[MetaOapg.properties.expiration_time, str, datetime, schemas.Unset] = schemas.unset,
                expiration_year: typing.Union[MetaOapg.properties.expiration_year, str, schemas.Unset] = schemas.unset,
                id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                is_pin_set: typing.Union[MetaOapg.properties.is_pin_set, bool, schemas.Unset] = schemas.unset,
                last_four: typing.Union[MetaOapg.properties.last_four, str, schemas.Unset] = schemas.unset,
                last_modified_time: typing.Union[MetaOapg.properties.last_modified_time, str, datetime, schemas.Unset] = schemas.unset,
                metadata: typing.Union['CardMetadata', schemas.Unset] = schemas.unset,
                reissue_reason: typing.Union[MetaOapg.properties.reissue_reason, str, schemas.Unset] = schemas.unset,
                reissued_from_id: typing.Union[MetaOapg.properties.reissued_from_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                reissued_to_id: typing.Union[MetaOapg.properties.reissued_to_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'all_of_1':
                return super().__new__(
                    cls,
                    *_args,
                    form=form,
                    account_id=account_id,
                    card_product_id=card_product_id,
                    creation_time=creation_time,
                    customer_id=customer_id,
                    emboss_name=emboss_name,
                    expiration_month=expiration_month,
                    expiration_time=expiration_time,
                    expiration_year=expiration_year,
                    id=id,
                    is_pin_set=is_pin_set,
                    last_four=last_four,
                    last_modified_time=last_modified_time,
                    metadata=metadata,
                    reissue_reason=reissue_reason,
                    reissued_from_id=reissued_from_id,
                    reissued_to_id=reissued_to_id,
                    type=type,
                    _configuration=_configuration,
                    **kwargs,
                )
        
        @classmethod
        @functools.lru_cache()
        def all_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                CardFormat,
                cls.all_of_1,
            ]


    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BaseCard':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.card_format import CardFormat
from synctera_client.model.card_metadata import CardMetadata
from synctera_client.model.emboss_name import EmbossName



from synctera_client.paths.persons_personal_ids_personal_id_id.delete import ApiFordelete
from synctera_client.paths.persons_personal_ids_personal_id_id.patch import ApiForpatch


class PersonsPersonalIdsPersonalIdId(
    ApiFordelete,
    ApiForpatch,
):
    pass



from synctera_client.paths.cards_gateways_gateway_id.get import ApiForget
from synctera_client.paths.cards_gateways_gateway_id.patch import ApiForpatch


class CardsGatewaysGatewayId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class AccountBase(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def access_status() -> typing.Type['AccountAccessStatus']:
                return AccountAccessStatus
            
            
            class account_number(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 50
            
            
            class account_number_masked(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 50
            account_purpose = schemas.StrSchema
        
            @staticmethod
            def account_type() -> typing.Type['AccountType']:
                return AccountType
            application_id = schemas.UUIDSchema
            
            
            class balances(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Balance']:
                        return Balance
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Balance'], typing.List['Balance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'balances':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Balance':
                    return super().__getitem__(i)
            
            
            class bank_routing(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 9
            creation_time = schemas.DateTimeSchema
            
            
            class currency(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    regex=[{
                        'pattern': r'^[A-Z]{3}$',  # noqa: E501
                    }]
            
            
            class customer_ids(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.UUIDSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'customer_ids':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
        
            @staticmethod
            def customer_type() -> typing.Type['CustomerType']:
                return CustomerType
            
            
            class exchange_rate_type(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 10
            
            
            class iban(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 34
            id = schemas.UUIDSchema
            is_account_pool = schemas.BoolSchema
            is_ach_enabled = schemas.BoolSchema
            is_card_enabled = schemas.BoolSchema
            is_external_card_enabled = schemas.BoolSchema
            is_p2p_enabled = schemas.BoolSchema
            is_sar_enabled = schemas.BoolSchema
            is_wire_enabled = schemas.BoolSchema
            last_updated_time = schemas.DateTimeSchema
            metadata = schemas.DictSchema
            nickname = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['Status']:
                return Status
            
            
            class swift_code(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 11
                    min_length = 8
            tenant = schemas.StrSchema
            __annotations__ = {
                "access_status": access_status,
                "account_number": account_number,
                "account_number_masked": account_number_masked,
                "account_purpose": account_purpose,
                "account_type": account_type,
                "application_id": application_id,
                "balances": balances,
                "bank_routing": bank_routing,
                "creation_time": creation_time,
                "currency": currency,
                "customer_ids": customer_ids,
                "customer_type": customer_type,
                "exchange_rate_type": exchange_rate_type,
                "iban": iban,
                "id": id,
                "is_account_pool": is_account_pool,
                "is_ach_enabled": is_ach_enabled,
                "is_card_enabled": is_card_enabled,
                "is_external_card_enabled": is_external_card_enabled,
                "is_p2p_enabled": is_p2p_enabled,
                "is_sar_enabled": is_sar_enabled,
                "is_wire_enabled": is_wire_enabled,
                "last_updated_time": last_updated_time,
                "metadata": metadata,
                "nickname": nickname,
                "status": status,
                "swift_code": swift_code,
                "tenant": tenant,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["access_status"]) -> 'AccountAccessStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_number"]) -> MetaOapg.properties.account_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_number_masked"]) -> MetaOapg.properties.account_number_masked: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_purpose"]) -> MetaOapg.properties.account_purpose: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_type"]) -> 'AccountType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["application_id"]) -> MetaOapg.properties.application_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balances"]) -> MetaOapg.properties.balances: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bank_routing"]) -> MetaOapg.properties.bank_routing: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_ids"]) -> MetaOapg.properties.customer_ids: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_type"]) -> 'CustomerType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exchange_rate_type"]) -> MetaOapg.properties.exchange_rate_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["iban"]) -> MetaOapg.properties.iban: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_account_pool"]) -> MetaOapg.properties.is_account_pool: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_ach_enabled"]) -> MetaOapg.properties.is_ach_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_card_enabled"]) -> MetaOapg.properties.is_card_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_external_card_enabled"]) -> MetaOapg.properties.is_external_card_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_p2p_enabled"]) -> MetaOapg.properties.is_p2p_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_sar_enabled"]) -> MetaOapg.properties.is_sar_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_wire_enabled"]) -> MetaOapg.properties.is_wire_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nickname"]) -> MetaOapg.properties.nickname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'Status': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["swift_code"]) -> MetaOapg.properties.swift_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["access_status", "account_number", "account_number_masked", "account_purpose", "account_type", "application_id", "balances", "bank_routing", "creation_time", "currency", "customer_ids", "customer_type", "exchange_rate_type", "iban", "id", "is_account_pool", "is_ach_enabled", "is_card_enabled", "is_external_card_enabled", "is_p2p_enabled", "is_sar_enabled", "is_wire_enabled", "last_updated_time", "metadata", "nickname", "status", "swift_code", "tenant", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["access_status"]) -> typing.Union['AccountAccessStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_number"]) -> typing.Union[MetaOapg.properties.account_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_number_masked"]) -> typing.Union[MetaOapg.properties.account_number_masked, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_purpose"]) -> typing.Union[MetaOapg.properties.account_purpose, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_type"]) -> typing.Union['AccountType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["application_id"]) -> typing.Union[MetaOapg.properties.application_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balances"]) -> typing.Union[MetaOapg.properties.balances, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bank_routing"]) -> typing.Union[MetaOapg.properties.bank_routing, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_ids"]) -> typing.Union[MetaOapg.properties.customer_ids, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_type"]) -> typing.Union['CustomerType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exchange_rate_type"]) -> typing.Union[MetaOapg.properties.exchange_rate_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["iban"]) -> typing.Union[MetaOapg.properties.iban, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_account_pool"]) -> typing.Union[MetaOapg.properties.is_account_pool, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_ach_enabled"]) -> typing.Union[MetaOapg.properties.is_ach_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_card_enabled"]) -> typing.Union[MetaOapg.properties.is_card_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_external_card_enabled"]) -> typing.Union[MetaOapg.properties.is_external_card_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_p2p_enabled"]) -> typing.Union[MetaOapg.properties.is_p2p_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_sar_enabled"]) -> typing.Union[MetaOapg.properties.is_sar_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_wire_enabled"]) -> typing.Union[MetaOapg.properties.is_wire_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> typing.Union[MetaOapg.properties.last_updated_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nickname"]) -> typing.Union[MetaOapg.properties.nickname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['Status', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["swift_code"]) -> typing.Union[MetaOapg.properties.swift_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tenant"]) -> typing.Union[MetaOapg.properties.tenant, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["access_status", "account_number", "account_number_masked", "account_purpose", "account_type", "application_id", "balances", "bank_routing", "creation_time", "currency", "customer_ids", "customer_type", "exchange_rate_type", "iban", "id", "is_account_pool", "is_ach_enabled", "is_card_enabled", "is_external_card_enabled", "is_p2p_enabled", "is_sar_enabled", "is_wire_enabled", "last_updated_time", "metadata", "nickname", "status", "swift_code", "tenant", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        access_status: typing.Union['AccountAccessStatus', schemas.Unset] = schemas.unset,
        account_number: typing.Union[MetaOapg.properties.account_number, str, schemas.Unset] = schemas.unset,
        account_number_masked: typing.Union[MetaOapg.properties.account_number_masked, str, schemas.Unset] = schemas.unset,
        account_purpose: typing.Union[MetaOapg.properties.account_purpose, str, schemas.Unset] = schemas.unset,
        account_type: typing.Union['AccountType', schemas.Unset] = schemas.unset,
        application_id: typing.Union[MetaOapg.properties.application_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        balances: typing.Union[MetaOapg.properties.balances, list, tuple, schemas.Unset] = schemas.unset,
        bank_routing: typing.Union[MetaOapg.properties.bank_routing, str, schemas.Unset] = schemas.unset,
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        customer_ids: typing.Union[MetaOapg.properties.customer_ids, list, tuple, schemas.Unset] = schemas.unset,
        customer_type: typing.Union['CustomerType', schemas.Unset] = schemas.unset,
        exchange_rate_type: typing.Union[MetaOapg.properties.exchange_rate_type, str, schemas.Unset] = schemas.unset,
        iban: typing.Union[MetaOapg.properties.iban, str, schemas.Unset] = schemas.unset,
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        is_account_pool: typing.Union[MetaOapg.properties.is_account_pool, bool, schemas.Unset] = schemas.unset,
        is_ach_enabled: typing.Union[MetaOapg.properties.is_ach_enabled, bool, schemas.Unset] = schemas.unset,
        is_card_enabled: typing.Union[MetaOapg.properties.is_card_enabled, bool, schemas.Unset] = schemas.unset,
        is_external_card_enabled: typing.Union[MetaOapg.properties.is_external_card_enabled, bool, schemas.Unset] = schemas.unset,
        is_p2p_enabled: typing.Union[MetaOapg.properties.is_p2p_enabled, bool, schemas.Unset] = schemas.unset,
        is_sar_enabled: typing.Union[MetaOapg.properties.is_sar_enabled, bool, schemas.Unset] = schemas.unset,
        is_wire_enabled: typing.Union[MetaOapg.properties.is_wire_enabled, bool, schemas.Unset] = schemas.unset,
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        nickname: typing.Union[MetaOapg.properties.nickname, str, schemas.Unset] = schemas.unset,
        status: typing.Union['Status', schemas.Unset] = schemas.unset,
        swift_code: typing.Union[MetaOapg.properties.swift_code, str, schemas.Unset] = schemas.unset,
        tenant: typing.Union[MetaOapg.properties.tenant, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AccountBase':
        return super().__new__(
            cls,
            *_args,
            access_status=access_status,
            account_number=account_number,
            account_number_masked=account_number_masked,
            account_purpose=account_purpose,
            account_type=account_type,
            application_id=application_id,
            balances=balances,
            bank_routing=bank_routing,
            creation_time=creation_time,
            currency=currency,
            customer_ids=customer_ids,
            customer_type=customer_type,
            exchange_rate_type=exchange_rate_type,
            iban=iban,
            id=id,
            is_account_pool=is_account_pool,
            is_ach_enabled=is_ach_enabled,
            is_card_enabled=is_card_enabled,
            is_external_card_enabled=is_external_card_enabled,
            is_p2p_enabled=is_p2p_enabled,
            is_sar_enabled=is_sar_enabled,
            is_wire_enabled=is_wire_enabled,
            last_updated_time=last_updated_time,
            metadata=metadata,
            nickname=nickname,
            status=status,
            swift_code=swift_code,
            tenant=tenant,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.account_access_status import AccountAccessStatus
from synctera_client.model.account_type import AccountType
from synctera_client.model.balance import Balance
from synctera_client.model.customer_type import CustomerType
from synctera_client.model.status import Status



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.accounts.post import CreateAccount
from synctera_client.paths.accounts_account_id_relationships.post import CreateAccountRelationship
from synctera_client.paths.accounts_products.post import CreateAccountResourceProduct
from synctera_client.paths.accounts_templates.post import CreateAccountTemplate
from synctera_client.paths.accounts_account_id_relationships_relationship_id.delete import DeleteAccountRelationship
from synctera_client.paths.accounts_templates_template_id.delete import DeleteAccountTemplate
from synctera_client.paths.accounts_account_id.get import GetAccount
from synctera_client.paths.accounts_account_id_relationships_relationship_id.get import GetAccountRelationship
from synctera_client.paths.accounts_templates_template_id.get import GetAccountTemplate
from synctera_client.paths.accounts_account_id_relationships.get import ListAccountRelationship
from synctera_client.paths.accounts_products.get import ListAccountResourceProducts
from synctera_client.paths.accounts_templates.get import ListAccountTemplates
from synctera_client.paths.accounts.get import ListAccounts
from synctera_client.paths.accounts_account_id.patch import PatchAccount
from synctera_client.paths.accounts_products_product_id.patch import PatchAccountProduct
from synctera_client.paths.accounts_account_id.put import UpdateAccount
from synctera_client.paths.accounts_account_id_relationships_relationship_id.put import UpdateAccountRelationship
from synctera_client.paths.accounts_templates_template_id.put import UpdateAccountTemplate


class AccountsApi(
    CreateAccount,
    CreateAccountRelationship,
    CreateAccountResourceProduct,
    CreateAccountTemplate,
    DeleteAccountRelationship,
    DeleteAccountTemplate,
    GetAccount,
    GetAccountRelationship,
    GetAccountTemplate,
    ListAccountRelationship,
    ListAccountResourceProducts,
    ListAccountTemplates,
    ListAccounts,
    PatchAccount,
    PatchAccountProduct,
    UpdateAccount,
    UpdateAccountRelationship,
    UpdateAccountTemplate,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from synctera_client.paths.persons_person_id.get import ApiForget
from synctera_client.paths.persons_person_id.patch import ApiForpatch


class PersonsPersonId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class EventTypeExplicit(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    All the webhook event types
    """
    
    @schemas.classproperty
    def ACCOUNT_CREATED(cls):
        return cls("ACCOUNT.CREATED")
    
    @schemas.classproperty
    def ACCOUNT_UPDATED(cls):
        return cls("ACCOUNT.UPDATED")
    
    @schemas.classproperty
    def APPLICATION_CREATED(cls):
        return cls("APPLICATION.CREATED")
    
    @schemas.classproperty
    def APPLICATION_UPDATED(cls):
        return cls("APPLICATION.UPDATED")
    
    @schemas.classproperty
    def BUSINESS_VERIFICATION_OUTCOME_UPDATED(cls):
        return cls("BUSINESS.VERIFICATION_OUTCOME.UPDATED")
    
    @schemas.classproperty
    def CARD_DIGITALWALLETTOKEN_CREATED(cls):
        return cls("CARD.DIGITALWALLETTOKEN.CREATED")
    
    @schemas.classproperty
    def CARD_DIGITALWALLETTOKEN_UPDATED(cls):
        return cls("CARD.DIGITALWALLETTOKEN.UPDATED")
    
    @schemas.classproperty
    def CARD_IMAGE_UPDATED(cls):
        return cls("CARD.IMAGE.UPDATED")
    
    @schemas.classproperty
    def CARD_UPDATED(cls):
        return cls("CARD.UPDATED")
    
    @schemas.classproperty
    def CASE_UPDATED(cls):
        return cls("CASE.UPDATED")
    
    @schemas.classproperty
    def CASH_PICKUP_CREATED(cls):
        return cls("CASH_PICKUP.CREATED")
    
    @schemas.classproperty
    def CASH_PICKUP_UPDATED(cls):
        return cls("CASH_PICKUP.UPDATED")
    
    @schemas.classproperty
    def CUSTOMER_KYC_OUTCOME_UPDATED(cls):
        return cls("CUSTOMER.KYC_OUTCOME.UPDATED")
    
    @schemas.classproperty
    def CUSTOMER_UPDATED(cls):
        return cls("CUSTOMER.UPDATED")
    
    @schemas.classproperty
    def EXTERNAL_CARD_CREATED(cls):
        return cls("EXTERNAL_CARD.CREATED")
    
    @schemas.classproperty
    def EXTERNAL_CARD_TRANSFER_CREATED(cls):
        return cls("EXTERNAL_CARD_TRANSFER.CREATED")
    
    @schemas.classproperty
    def INTEREST_MONTHLY_PAYOUT(cls):
        return cls("INTEREST.MONTHLY_PAYOUT")
    
    @schemas.classproperty
    def INTERNAL_TRANSFER_SUCCEEDED(cls):
        return cls("INTERNAL_TRANSFER.SUCCEEDED")
    
    @schemas.classproperty
    def PAYMENT_SCHEDULE_CREATED(cls):
        return cls("PAYMENT_SCHEDULE.CREATED")
    
    @schemas.classproperty
    def PAYMENT_SCHEDULE_PAYMENT_CREATED(cls):
        return cls("PAYMENT_SCHEDULE.PAYMENT.CREATED")
    
    @schemas.classproperty
    def PAYMENT_SCHEDULE_UPDATED(cls):
        return cls("PAYMENT_SCHEDULE.UPDATED")
    
    @schemas.classproperty
    def PERSON_UPDATED(cls):
        return cls("PERSON.UPDATED")
    
    @schemas.classproperty
    def PERSON_VERIFICATION_OUTCOME_UPDATED(cls):
        return cls("PERSON.VERIFICATION_OUTCOME.UPDATED")
    
    @schemas.classproperty
    def STATEMENT_CREATED(cls):
        return cls("STATEMENT.CREATED")
    
    @schemas.classproperty
    def TRANSACTION_PENDING_CREATED(cls):
        return cls("TRANSACTION.PENDING.CREATED")
    
    @schemas.classproperty
    def TRANSACTION_PENDING_UPDATED(cls):
        return cls("TRANSACTION.PENDING.UPDATED")
    
    @schemas.classproperty
    def TRANSACTION_POSTED_CREATED(cls):
        return cls("TRANSACTION.POSTED.CREATED")
    
    @schemas.classproperty
    def TRANSACTION_POSTED_UPDATED(cls):
        return cls("TRANSACTION.POSTED.UPDATED")



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Wire(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "creation_time",
            "transaction_id",
            "amount",
            "last_updated_time",
            "originating_account_id",
            "receiving_account_id",
            "effective_date",
            "sender_reference_id",
            "currency",
            "id",
            "customer_id",
            "status",
        }
        
        class properties:
            amount = schemas.IntSchema
            creation_time = schemas.DateTimeSchema
            currency = schemas.StrSchema
            customer_id = schemas.UUIDSchema
            effective_date = schemas.DateSchema
            id = schemas.UUIDSchema
            last_updated_time = schemas.DateTimeSchema
            originating_account_id = schemas.UUIDSchema
            receiving_account_id = schemas.UUIDSchema
            sender_reference_id = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("PENDING")
                
                @schemas.classproperty
                def COMPLETED(cls):
                    return cls("COMPLETED")
                
                @schemas.classproperty
                def CANCELED(cls):
                    return cls("CANCELED")
                
                @schemas.classproperty
                def DECLINED(cls):
                    return cls("DECLINED")
            transaction_id = schemas.UUIDSchema
            bank_message = schemas.StrSchema
            
            
            class direction(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def IN(cls):
                    return cls("IN")
                
                @schemas.classproperty
                def OUT(cls):
                    return cls("OUT")
            recipient_message = schemas.StrSchema
            __annotations__ = {
                "amount": amount,
                "creation_time": creation_time,
                "currency": currency,
                "customer_id": customer_id,
                "effective_date": effective_date,
                "id": id,
                "last_updated_time": last_updated_time,
                "originating_account_id": originating_account_id,
                "receiving_account_id": receiving_account_id,
                "sender_reference_id": sender_reference_id,
                "status": status,
                "transaction_id": transaction_id,
                "bank_message": bank_message,
                "direction": direction,
                "recipient_message": recipient_message,
            }
    
    creation_time: MetaOapg.properties.creation_time
    transaction_id: MetaOapg.properties.transaction_id
    amount: MetaOapg.properties.amount
    last_updated_time: MetaOapg.properties.last_updated_time
    originating_account_id: MetaOapg.properties.originating_account_id
    receiving_account_id: MetaOapg.properties.receiving_account_id
    effective_date: MetaOapg.properties.effective_date
    sender_reference_id: MetaOapg.properties.sender_reference_id
    currency: MetaOapg.properties.currency
    id: MetaOapg.properties.id
    customer_id: MetaOapg.properties.customer_id
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["originating_account_id"]) -> MetaOapg.properties.originating_account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receiving_account_id"]) -> MetaOapg.properties.receiving_account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_reference_id"]) -> MetaOapg.properties.sender_reference_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_id"]) -> MetaOapg.properties.transaction_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bank_message"]) -> MetaOapg.properties.bank_message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["direction"]) -> MetaOapg.properties.direction: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["recipient_message"]) -> MetaOapg.properties.recipient_message: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "creation_time", "currency", "customer_id", "effective_date", "id", "last_updated_time", "originating_account_id", "receiving_account_id", "sender_reference_id", "status", "transaction_id", "bank_message", "direction", "recipient_message", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["originating_account_id"]) -> MetaOapg.properties.originating_account_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receiving_account_id"]) -> MetaOapg.properties.receiving_account_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_reference_id"]) -> MetaOapg.properties.sender_reference_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_id"]) -> MetaOapg.properties.transaction_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bank_message"]) -> typing.Union[MetaOapg.properties.bank_message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["direction"]) -> typing.Union[MetaOapg.properties.direction, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["recipient_message"]) -> typing.Union[MetaOapg.properties.recipient_message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "creation_time", "currency", "customer_id", "effective_date", "id", "last_updated_time", "originating_account_id", "receiving_account_id", "sender_reference_id", "status", "transaction_id", "bank_message", "direction", "recipient_message", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, ],
        transaction_id: typing.Union[MetaOapg.properties.transaction_id, str, uuid.UUID, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, ],
        originating_account_id: typing.Union[MetaOapg.properties.originating_account_id, str, uuid.UUID, ],
        receiving_account_id: typing.Union[MetaOapg.properties.receiving_account_id, str, uuid.UUID, ],
        effective_date: typing.Union[MetaOapg.properties.effective_date, str, date, ],
        sender_reference_id: typing.Union[MetaOapg.properties.sender_reference_id, str, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        bank_message: typing.Union[MetaOapg.properties.bank_message, str, schemas.Unset] = schemas.unset,
        direction: typing.Union[MetaOapg.properties.direction, str, schemas.Unset] = schemas.unset,
        recipient_message: typing.Union[MetaOapg.properties.recipient_message, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Wire':
        return super().__new__(
            cls,
            *_args,
            creation_time=creation_time,
            transaction_id=transaction_id,
            amount=amount,
            last_updated_time=last_updated_time,
            originating_account_id=originating_account_id,
            receiving_account_id=receiving_account_id,
            effective_date=effective_date,
            sender_reference_id=sender_reference_id,
            currency=currency,
            id=id,
            customer_id=customer_id,
            status=status,
            bank_message=bank_message,
            direction=direction,
            recipient_message=recipient_message,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Shipping(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Details about the shipping method. If supplied this will override the default shipping address of the customer or account.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def address() -> typing.Type['Address1']:
                return Address1
            care_of_line = schemas.StrSchema
            is_expedited_fulfillment = schemas.BoolSchema
            
            
            class method(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def LOCAL_MAIL(cls):
                    return cls("LOCAL_MAIL")
                
                @schemas.classproperty
                def TWO_DAY(cls):
                    return cls("TWO_DAY")
                
                @schemas.classproperty
                def OVERNIGHT(cls):
                    return cls("OVERNIGHT")
                
                @schemas.classproperty
                def INTERNATIONAL(cls):
                    return cls("INTERNATIONAL")
            
            
            class phone_number(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def recipient_name() -> typing.Type['RecipientName']:
                return RecipientName
            __annotations__ = {
                "address": address,
                "care_of_line": care_of_line,
                "is_expedited_fulfillment": is_expedited_fulfillment,
                "method": method,
                "phone_number": phone_number,
                "recipient_name": recipient_name,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> 'Address1': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["care_of_line"]) -> MetaOapg.properties.care_of_line: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_expedited_fulfillment"]) -> MetaOapg.properties.is_expedited_fulfillment: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["method"]) -> MetaOapg.properties.method: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phone_number"]) -> MetaOapg.properties.phone_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["recipient_name"]) -> 'RecipientName': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "care_of_line", "is_expedited_fulfillment", "method", "phone_number", "recipient_name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union['Address1', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["care_of_line"]) -> typing.Union[MetaOapg.properties.care_of_line, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_expedited_fulfillment"]) -> typing.Union[MetaOapg.properties.is_expedited_fulfillment, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["method"]) -> typing.Union[MetaOapg.properties.method, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phone_number"]) -> typing.Union[MetaOapg.properties.phone_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["recipient_name"]) -> typing.Union['RecipientName', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "care_of_line", "is_expedited_fulfillment", "method", "phone_number", "recipient_name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        address: typing.Union['Address1', schemas.Unset] = schemas.unset,
        care_of_line: typing.Union[MetaOapg.properties.care_of_line, str, schemas.Unset] = schemas.unset,
        is_expedited_fulfillment: typing.Union[MetaOapg.properties.is_expedited_fulfillment, bool, schemas.Unset] = schemas.unset,
        method: typing.Union[MetaOapg.properties.method, str, schemas.Unset] = schemas.unset,
        phone_number: typing.Union[MetaOapg.properties.phone_number, str, schemas.Unset] = schemas.unset,
        recipient_name: typing.Union['RecipientName', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Shipping':
        return super().__new__(
            cls,
            *_args,
            address=address,
            care_of_line=care_of_line,
            is_expedited_fulfillment=is_expedited_fulfillment,
            method=method,
            phone_number=phone_number,
            recipient_name=recipient_name,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.address1 import Address1
from synctera_client.model.recipient_name import RecipientName
